@@ -21,8 +21,6 @@ from scipy.stats import hypergeom
 from collections import defaultdict
 from .PTE_config import db_config
 
-# todo: conver all "concept" and "term" to "trait"
-# todo: Enricher initialize
 
 class enrichment_result:
     def __init__(self):
@@ -50,15 +48,10 @@ class Association:
         self.evidence = evidence
 
 class Background:
-    # todo: background statistics
     def __init__(self,):
 
         self.initialized = False
 
-        # self.association_list = []
-        # self.term_set = set()
-
-        # fixme: useful?
         self.gene_set = set()
         self.trait_set = set()
 
@@ -101,11 +94,9 @@ class Gene_Ontology_enrichment:
 
     def __init__(self, source_set: set):
 
-        # fixme: config file or option ?
         self.gene_term_file = db_config['PT_anno_file']
         self.obo_file = db_config['ontology_file']
 
-        # todo: source select.
         self.background_source = {'Oryzabase', 'TAS', 'funRiceGene', 'SemanticComputing', 'ExactMatching'}
         wrong_source = source_set - self.background_source
         if wrong_source:
@@ -114,9 +105,6 @@ class Gene_Ontology_enrichment:
                             f', "SemanticComputing" or "ExactMatching".')
         self.source_set = source_set
 
-
-        # fixme: new data structure
-
         self.id_to_trait = defaultdict(trait_concept)
 
         self.rap_background = Background()
@@ -129,29 +117,8 @@ class Gene_Ontology_enrichment:
 
         self.enrich_dataframe = ''
 
-        # self.db_check()
-        # self.load_ontology()
-        # self.load_background_data()
-
-    # todo: ftp for data download.
-    @staticmethod
-    def db_check():
-        """
-        1. Check if the data is exist.
-        2. Download data.
-        """
-        if not os.path.exists(db_config['db_path']):
-            os.mkdir(db_config['db_path'])
-        if not os.path.exists(db_config['ontology_file']):
-            print('Downloading: {0} for package.'.format(os.path.basename(db_config['ontology_file'])))
-            url = db_config['ontology_url']
-            file_name = wget.download(url, out=db_config['ontology_file'])
-            # print(file_name)
-        if not os.path.exists(db_config['PT_anno_file']):
-            print('Downloading: {0} for package.'.format(db_config['PT_anno_file']))
-            url = db_config['PT_anno_url']
-            file_name = wget.download(url, out=db_config['PT_anno_file'])
-            # print(file_name)
+        self.load_ontology()
+        self.load_background_data()
 
     # todo: ontology class
     #       parent, child or other.
@@ -298,7 +265,6 @@ class Gene_Ontology_enrichment:
                 self.enrich_result.Gene_Ratio[trait_id] =  x / k
                 self.enrich_result.BG_Ratio[trait_id] = k / N
 
-        # todo-done: check here
         # todo: method need to give users options
         self.p_adjust(p_adjust_method)
         self.q_value()
@@ -307,15 +273,14 @@ class Gene_Ontology_enrichment:
         sorted_result = sorted(self.enrich_result.terms_p_value.keys(),
                                key=lambda x: self.enrich_result.terms_p_value[x])
 
-        # todo: 表格对齐输出
-        print(f'Trait id\tTrait name\tp-value\tp-adjust\tq-value')
+        print(f'{"Trait id":<10}\t{"Trait name":<50}\t{"p-value":<8}\t{"p-adjust":<8}'
+              f'\t{"q-value":<8}')
         for trait_id in sorted_result:
-            print(f'{trait_id}\t{self.id_to_trait[trait_id].trait_name}\t'
-                  f'{self.enrich_result.terms_p_value[trait_id]}\t'
-                  f'{self.enrich_result.terms_p_adjust[trait_id]}\t'
-                  f'{self.enrich_result.terms_q_value[trait_id]}')
+            print(f'{trait_id:<10}\t{self.id_to_trait[trait_id].trait_name:<50}\t'
+                  f'{self.enrich_result.terms_p_value[trait_id]:<.2e}\t'
+                  f'{self.enrich_result.terms_p_adjust[trait_id]:<.2e}\t'
+                  f'{self.enrich_result.terms_q_value[trait_id]}:<.2e')
 
-        # todo: add prefix
         if save_result:
             if not save_path:
                 raise TypeError('You have to provide a path to save the result.')
@@ -479,11 +444,9 @@ class Gene_Ontology_enrichment:
               ggtitle('Bar Plot')
               )
 
-
-        # fixme: save plot
-        # if save_path:
-        #     save_file = f'{save_path}/{prefix}.bar.new.png'
-        #     p1.save(save_file, width=7, height=4, dpi=150)
+        if save_plot:
+            save_file = f'{save_path}/{prefix}.bar.new.png'
+            p1.save(save_file, width=7, height=4, dpi=150)
 
         return p1
 
@@ -491,7 +454,7 @@ class Gene_Ontology_enrichment:
 
         self.enrich_dataframe = self.enrich_dataframe.sort_values(by='p-value')
 
-        # fixme: shape='Class'
+        # shape='Class'
         p2 = (ggplot(self.enrich_dataframe) +
               geom_point(aes(
                   x='GeneRatio', y='ID_Name',
@@ -504,30 +467,9 @@ class Gene_Ontology_enrichment:
               ggtitle('Babble Plot')
               )
 
-        # fixme: save plot
         if save_path:
             save_file = f'{save_path}/{prefix}.bubble2.png'
             p2.save(save_file, width=6, height=4, dpi=150)
 
         return p2
 
-
-    # def draw_bubble_new_2(self, save_path='../result',  prefix='EnrRiceTrait', save_plot=False):
-    #
-    #     # fixme: color: class
-    #     # fixme: z-score
-    #     p3 = (ggplot(self.enrich_dataframe) +
-    #           geom_point(aes(
-    #               x='z-score', y='neg_log_p_value',
-    #               size='Count', color='Class', fill='Class')) +
-    #           geom_text(aes(
-    #               x='z-score', y='neg_log_p_value',
-    #               size=12, label='highest_neg_log_p_value_label')) +
-    #           xlab('Z-Score') + ylab('Negative Log P-Value') +
-    #           xlim(-3, 7) +
-    #           scale_color_cmap_d(name='Accent') +
-    #           scale_fill_cmap_d(name='Accent') +
-    #           ggtitle('Babble Plot')
-    #           )
-
-
